=======
History
=======

Version 1
---------

* 1.1.0 (2022.09.16)
    * Add user-defined file format for auxiliary graphs

* 1.0.1 (2022.09.02)
	* Fix bugs and typos

* 1.0.0 (2022.08.15)
	* First release on PyPI.
	  
Version 0
---------

* 0.1.3 (2022-08-01)
	* Fourth pre-release on PyPI

* 0.1.2 (2022-08-01)
	* Third pre-release on PyPI

* 0.1.1 (2022-07-31)
	* Second pre-release on PyPI

* 0.1.0 (2022-07-28)
	* First pre-release on PyPI

